.. sqla_helpers documentation master file, created by
   sphinx-quickstart on Fri Jan 25 09:52:52 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to sqla_helpers's documentation!
========================================

Contents:

.. toctree::
   :glob:

   sqla*
   dev*




Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

